| add_qsig | R Documentation |
Adds Benjamini-Hochberg adjusted q-values and a simple significance code column based on p-values contained in a data frame.
add_qsig(df)
df |
A data frame containing at least a numeric column
|
The function:
Computes q_value using p.adjust(method = "BH").
Creates a sig column with significance codes:
"***" for q_value <= 0.001
"**" for 0.001 < q_value <= 0.01
"*" for 0.01 < q_value <= 0.05
"" otherwise
The input data frame with added columns q_value and
sig. If df is NULL or empty, it is returned as is.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.