| .build_model_with_floor | R Documentation |
Takes a Stan program as a single string and replaces the declaration
of the scalar constant FLOOR with a user supplied numeric
value, then compiles it as a CmdStanR model with threading enabled.
.build_model_with_floor(stan_code, floor_value)
stan_code |
Character string containing the Stan program. It
must include a line of the form |
floor_value |
Numeric scalar used to set the constant
|
The replacement is performed using a regular expression,
so the Stan code must follow the pattern used in the bivariate
hurdle model templates of this package. The compiled model has
stan_threads turned on via cpp_options.
A CmdStanModel object (requires 'cmdstanr' package).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.