| .read_te_all | R Documentation |
Helper to load transfer entropy results from a combined CSV file or from separate per-type files (counts, rates, binary) if the combined file is not available.
.read_te_all(dir_csv)
dir_csv |
Character scalar; directory where the transfer entropy CSV files are stored. The function first looks for
and combines them into a single data frame with a |
A data frame with transfer entropy results (potentially
combining several types) or NULL if no files are found.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.