| .scalar1_chr | R Documentation |
Helper to coerce an object to character and return a single scalar
if possible. If the input has length not equal to 1 or is NA,
a default value is returned.
.scalar1_chr(x, default = NA_character_)
x |
Object to be coerced to character. |
default |
Character scalar returned when a valid scalar cannot
be extracted (default is |
A character scalar or default if extraction fails.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.