rc_auto: Read CSV with automatic delimiter detection

View source: R/extractor.R

rc_autoR Documentation

Read CSV with automatic delimiter detection

Description

Attempts to read a CSV file using several strategies, trying to infer whether the delimiter is a comma or a semicolon. It first tries readr::read_csv(), optionally falls back to readr::read_csv2() when a semicolon is detected or the first attempt fails, and finally tries base utils::read.csv() as a last resort.

Usage

rc_auto(fp)

Arguments

fp

Character scalar; path to the CSV file.

Value

A data frame if a valid non-empty table could be read, or NULL if all attempts fail.


bivarhr documentation built on July 7, 2026, 1:06 a.m.